@@ -2,7 +2,7 @@
 package CPAN::Mirrored::By;
 use strict;
 use vars qw($VERSION);
-$VERSION = sprintf "%.2f", substr(q$Rev: 386 $,4)/100;
+$VERSION = sprintf "%.2f", substr(q$Rev: 399 $,4)/100;
 
 sub new { 
     my($self,@arg) = @_;
@@ -21,7 +21,7 @@ use File::Basename ();
 use File::Path ();
 use File::Spec;
 use vars qw($VERSION);
-$VERSION = sprintf "%.2f", substr(q$Rev: 386 $,4)/100;
+$VERSION = sprintf "%.2f", substr(q$Rev: 399 $,4)/100;
 
 =head1 NAME
 
@@ -292,6 +292,9 @@ Shall we use it as the general CPAN build and cache directory?
 	$path = "";
     }
     $path ||= $ENV{SHELL};
+    if (!$path && $^O eq 'MSWin32') {
+	$path = Win32::IsWinNT() ? "cmd.exe" : "command.com";
+    }
     if ($^O eq 'MacOS') {
         $CPAN::Config->{'shell'} = 'not_here';
     } else {
